@@ -2,7 +2,7 @@
 
 import logging
 from typing import Any, Optional
-from aiohttp import ClientResponseError, ClientSession
+from aiohttp import ClientSession
 import base64
 import aiohttp
 from cryptography.hazmat.backends import default_backend
