@@ -15,8 +15,10 @@ class AidotAuthTokenExpired(AidotError):
     """Authentication failed because token is invalid or expired."""
 
 class AidotAuthFailed(AidotError):
-    """Authentication failed because MFA verification code is required."""
+    """Authentication failed"""
 
 class AidotUserOrPassIncorrect(AidotError):
-    """The password or email address is incorrect."""
-    
\ No newline at end of file
+    """Authentication failed"""
+
+class AidotOSError(Exception):
+    """Aidot exception."""
