@@ -4,9 +4,6 @@ import binascii
 import time
 from datetime import datetime
 import json
-import threading
-import colorsys
-from time import sleep
 import asyncio
 import logging
 
